import * as i0 from '@angular/core';
import { NgModule, inject, Injectable, HostListener, Input, ChangeDetectionStrategy, Component, ContentChild } from '@angular/core';
import * as i4 from '@angular/common';
import { CommonModule } from '@angular/common';
import { BehaviorSubject, Subject, fromEvent } from 'rxjs';
import { take, takeUntil, takeWhile } from 'rxjs/operators';
import * as i1 from '@skyux/i18n';
import { SkyLibResourcesService, SkyI18nModule } from '@skyux/i18n';
import * as i1$1 from '@skyux/core';
import { SkyMediaQueryService, SkyResponsiveHostDirective } from '@skyux/core';
import { takeUntilDestroyed, toSignal } from '@angular/core/rxjs-interop';
import * as i2 from '@skyux/icon';
import { SkyIconModule } from '@skyux/icon';
import { trigger, transition, state, style, animate } from '@angular/animations';

/* istanbul ignore file */
/**
 * NOTICE: DO NOT MODIFY THIS FILE!
 * The contents of this file were automatically generated by
 * the 'ng generate @skyux/i18n:lib-resources-module lib/modules/shared/sky-split-view' schematic.
 * To update this file, simply rerun the command.
 */
const RESOURCES = {
    'EN-US': {
        skyux_split_view_resize_handle: {
            message: 'Resize the drawer panel. Use right arrow key to expand and left arrow key to shrink.',
        },
        skyux_split_view_back_to_list: { message: 'Back to list' },
    },
    'FR-CA': {
        skyux_split_view_resize_handle: {
            message: 'Redimensionnez le panneau du menu latéral. Utilisez la flèche de droite pour agrandir et la flèche de gauche pour réduire.',
        },
        skyux_split_view_back_to_list: { message: 'Retour à la liste' },
    },
};
SkyLibResourcesService.addResources(RESOURCES);
/**
 * Import into any component library module that needs to use resource strings.
 */
class SkySplitViewResourcesModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewResourcesModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewResourcesModule, exports: [SkyI18nModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewResourcesModule, imports: [SkyI18nModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewResourcesModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [SkyI18nModule],
                }]
        }] });

/**
 * Internal service for operations between the split view drawer and workspace.
 * @internal
 */
class SkySplitViewService {
    get backButtonTextStream() {
        return this.#_backButtonTextStream;
    }
    set isMobile(value) {
        this.#_isMobile = value;
    }
    get isMobile() {
        return this.#_isMobile;
    }
    get isMobileStream() {
        return this.#_isMobileStream;
    }
    #_backButtonTextStream;
    #_isMobile;
    #_isMobileStream;
    constructor(resources) {
        this.drawerVisible = new BehaviorSubject(true);
        this.#_backButtonTextStream = new BehaviorSubject('');
        this.#_isMobile = false;
        this.#_isMobileStream = new BehaviorSubject(false);
        // Set default back button text.
        resources
            .getString('skyux_split_view_back_to_list')
            .pipe(take(1))
            .subscribe((resource) => {
            this.updateBackButtonText(resource);
        });
        // Set breakpoint.
        inject(SkyMediaQueryService)
            .breakpointChange.pipe(takeUntilDestroyed())
            .subscribe((breakpoint) => {
            const nowMobile = breakpoint === 'xs';
            if (nowMobile && !this.isMobile) {
                // switching to mobile
                this.#_isMobileStream.next(true);
                this.drawerVisible.next(false);
            }
            else if (!nowMobile && this.isMobile) {
                // switching to widescreen
                this.#_isMobileStream.next(false);
                this.drawerVisible.next(true);
            }
            this.isMobile = nowMobile;
        });
    }
    backButtonClick() {
        this.drawerVisible.next(true);
    }
    updateBackButtonText(text) {
        this.#_backButtonTextStream.next(text);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewService, deps: [{ token: i1.SkyLibResourcesService }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1.SkyLibResourcesService }] });

let skySplitViewNextId = 0;
/**
 * Specifies the content to display in the split view's list panel.
 */
class SkySplitViewDrawerComponent {
    /**
     * Sets the list panel's width in pixels.
     * @default 320
     */
    set width(value) {
        if (value) {
            this.#_width = Number(value);
            this.#changeDetectorRef.markForCheck();
        }
    }
    get width() {
        // TODO: Logic in a getter is a SKY UX anti-pattern, but fixing this would
        // require a significant amount of refactoring.
        if (this.isMobile) {
            return undefined;
        }
        if (this.#_width !== undefined) {
            if (this.#_width > this.widthMax) {
                return this.widthMax;
            }
            else if (this.#_width < this.widthMin) {
                return this.widthMin;
            }
        }
        return this.#_width || this.widthDefault;
    }
    #isDragging;
    #ngUnsubscribe;
    #xCoord;
    #changeDetectorRef;
    #coreAdapterService;
    #splitViewSvc;
    #windowRef;
    #_width;
    constructor(changeDetectorRef, coreAdapterService, splitViewSvc, windowRef) {
        this.isMobile = false;
        this.widthDefault = 320;
        // Max needs to start as something to allow input range to work.
        // This value is updated as soon as the user takes action.
        this.widthMax = 9999;
        this.widthMin = 100;
        this.widthTolerance = 100;
        this.#isDragging = false;
        this.#ngUnsubscribe = new Subject();
        this.#xCoord = 0;
        this.#changeDetectorRef = changeDetectorRef;
        this.#coreAdapterService = coreAdapterService;
        this.#splitViewSvc = splitViewSvc;
        this.#windowRef = windowRef;
        this.splitViewDrawerId = `sky-split-view-drawer-${++skySplitViewNextId}`;
    }
    ngOnInit() {
        this.#setMaxWidth();
        this.#splitViewSvc.isMobileStream
            .pipe(takeUntil(this.#ngUnsubscribe))
            .subscribe((mobile) => {
            this.isMobile = mobile;
            this.#changeDetectorRef.markForCheck();
        });
    }
    ngOnDestroy() {
        this.#ngUnsubscribe.next();
        this.#ngUnsubscribe.complete();
    }
    onResizeHandleMouseDown(event) {
        event.preventDefault();
        event.stopPropagation();
        this.#setMaxWidth();
        this.#isDragging = true;
        this.#xCoord = event.clientX;
        this.#coreAdapterService.toggleIframePointerEvents(false);
        fromEvent(document, 'mousemove')
            .pipe(takeUntil(this.#ngUnsubscribe), takeWhile(() => {
            return this.#isDragging;
        }))
            .subscribe((moveEvent) => {
            this.onMouseMove(moveEvent);
        });
        fromEvent(document, 'mouseup')
            .pipe(takeUntil(this.#ngUnsubscribe), takeWhile(() => {
            return this.#isDragging;
        }))
            .subscribe(() => {
            this.onHandleRelease();
        });
    }
    onMouseMove(event) {
        /* Sanity check */
        /* istanbul ignore if */
        if (!this.#isDragging || this.width === undefined) {
            return;
        }
        const offsetX = event.clientX - this.#xCoord;
        let width = this.width;
        width += offsetX;
        if (width < this.widthMin || width > this.widthMax) {
            return;
        }
        this.width = width;
        this.#xCoord = event.clientX;
        this.#changeDetectorRef.markForCheck();
    }
    onHandleRelease() {
        this.#isDragging = false;
        this.#coreAdapterService.toggleIframePointerEvents(true);
        this.#changeDetectorRef.markForCheck();
    }
    onResizeHandleChange(event) {
        this.width = +event.target.value;
        this.#setMaxWidth();
    }
    onWindowResize() {
        const window = this.#windowRef.nativeWindow;
        // If window size is smaller than width + tolerance, shrink width.
        if (!this.isMobile &&
            this.width !== undefined &&
            window.innerWidth < this.width + this.widthTolerance) {
            this.width = window.innerWidth - this.widthTolerance;
        }
    }
    #setMaxWidth() {
        const splitView = this.#splitViewSvc.splitViewElementRef?.nativeElement.querySelector('.sky-split-view');
        this.widthMax = splitView.clientWidth - this.widthTolerance;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewDrawerComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: i1$1.SkyCoreAdapterService }, { token: SkySplitViewService }, { token: i1$1.SkyAppWindowRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.14", type: SkySplitViewDrawerComponent, isStandalone: true, selector: "sky-split-view-drawer", inputs: { ariaLabel: "ariaLabel", width: "width" }, host: { listeners: { "window:resize": "onWindowResize($event)" } }, ngImport: i0, template: "<div\n  class=\"sky-split-view-drawer\"\n  role=\"region\"\n  tabindex=\"0\"\n  [attr.aria-label]=\"ariaLabel\"\n  [id]=\"splitViewDrawerId\"\n  [style.width.px]=\"width\"\n>\n  <ng-content />\n  @if (!isMobile && width !== undefined) {\n    <input\n      aria-orientation=\"vertical\"\n      class=\"sky-split-view-resize-handle\"\n      step=\"10\"\n      type=\"range\"\n      [attr.aria-controls]=\"splitViewDrawerId\"\n      [attr.aria-label]=\"'skyux_split_view_resize_handle' | skyLibResources\"\n      [attr.aria-valuemax]=\"widthMax\"\n      [attr.aria-valuemin]=\"widthMin\"\n      [attr.aria-valuenow]=\"width\"\n      [attr.aria-valuetext]=\"width + ' pixels wide'\"\n      [max]=\"widthMax\"\n      [min]=\"widthMin\"\n      [style.left.px]=\"width - 7\"\n      [value]=\"width\"\n      (change)=\"onResizeHandleChange($event)\"\n      (mousedown)=\"onResizeHandleMouseDown($event)\"\n    />\n  }\n</div>\n", styles: [".sky-split-view-drawer:not(.sky-theme-modern *){--sky-override-split-view-drawer-background-color: #ffffff;--sky-override-split-view-drawer-border-right: 1px solid #cdcfd2;--sky-override-split-view-resize-handle-border-focus: none;--sky-override-split-view-resize-handle-outline-focus: auto;--sky-override-split-view-resize-handle-width: 14px}:host-context(.sky-theme-modern:not(.sky-theme-brand-base)) .sky-split-view-drawer{--sky-override-split-view-resize-handle-box-shadow-focus: var( --sky-elevation-focus )}.sky-split-view-drawer{background:var(--sky-override-split-view-drawer-background-color, transparent);overflow:auto;height:100%;width:100%}@media (min-width: 768px){:host .sky-split-view-drawer{border-right:var(--sky-override-split-view-drawer-border-right, var(--sky-border-width-divider) solid var(--sky-color-border-divider))}}:host-context(.sky-responsive-container-sm) .sky-split-view-drawer,:host-context(.sky-responsive-container-md) .sky-split-view-drawer,:host-context(.sky-responsive-container-lg) .sky-split-view-drawer{border-right:var(--sky-override-split-view-drawer-border-right, var(--sky-border-width-divider) solid var(--sky-color-border-divider))}.sky-split-view-resize-handle{-webkit-appearance:none;-moz-appearance:none;height:100%;width:var(--sky-override-split-view-resize-handle-width, var(--sky-size-width-resize_handle));position:absolute;z-index:999;cursor:ew-resize;padding:0;border:0;background:transparent;display:block;top:0;bottom:0;transition:box-shadow .15s}.sky-split-view-resize-handle:focus{border:var(--sky-override-split-view-resize-handle-border-focus, solid var(--sky-border-width-action-focus) var(--sky-color-border-action-tertiary-focus));box-shadow:var(--sky-override-split-view-resize-handle-box-shadow-focus, none);outline:var(--sky-override-split-view-resize-handle-outline-focus, none)}.sky-split-view-resize-handle::-moz-range-thumb,.sky-split-view-resize-handle::-moz-range-track{-webkit-appearance:none;-moz-appearance:none;width:0;height:0;border-radius:0;border:0 none;background:none;display:none}.sky-split-view-resize-handle::-ms-thumb,.sky-split-view-resize-handle::-ms-track{-webkit-appearance:none;-moz-appearance:none;width:0;height:0;border-radius:0;border:0 none;background:none;display:none}.sky-split-view-resize-handle::-webkit-slider-thumb{-webkit-appearance:none;-moz-appearance:none;width:0;height:0;border-radius:0;border:0 none;background:none;display:none}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "ngmodule", type: SkySplitViewResourcesModule }, { kind: "pipe", type: i1.SkyLibResourcesPipe, name: "skyLibResources" }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewDrawerComponent, decorators: [{
            type: Component,
            args: [{ changeDetection: ChangeDetectionStrategy.OnPush, imports: [CommonModule, SkySplitViewResourcesModule], selector: 'sky-split-view-drawer', template: "<div\n  class=\"sky-split-view-drawer\"\n  role=\"region\"\n  tabindex=\"0\"\n  [attr.aria-label]=\"ariaLabel\"\n  [id]=\"splitViewDrawerId\"\n  [style.width.px]=\"width\"\n>\n  <ng-content />\n  @if (!isMobile && width !== undefined) {\n    <input\n      aria-orientation=\"vertical\"\n      class=\"sky-split-view-resize-handle\"\n      step=\"10\"\n      type=\"range\"\n      [attr.aria-controls]=\"splitViewDrawerId\"\n      [attr.aria-label]=\"'skyux_split_view_resize_handle' | skyLibResources\"\n      [attr.aria-valuemax]=\"widthMax\"\n      [attr.aria-valuemin]=\"widthMin\"\n      [attr.aria-valuenow]=\"width\"\n      [attr.aria-valuetext]=\"width + ' pixels wide'\"\n      [max]=\"widthMax\"\n      [min]=\"widthMin\"\n      [style.left.px]=\"width - 7\"\n      [value]=\"width\"\n      (change)=\"onResizeHandleChange($event)\"\n      (mousedown)=\"onResizeHandleMouseDown($event)\"\n    />\n  }\n</div>\n", styles: [".sky-split-view-drawer:not(.sky-theme-modern *){--sky-override-split-view-drawer-background-color: #ffffff;--sky-override-split-view-drawer-border-right: 1px solid #cdcfd2;--sky-override-split-view-resize-handle-border-focus: none;--sky-override-split-view-resize-handle-outline-focus: auto;--sky-override-split-view-resize-handle-width: 14px}:host-context(.sky-theme-modern:not(.sky-theme-brand-base)) .sky-split-view-drawer{--sky-override-split-view-resize-handle-box-shadow-focus: var( --sky-elevation-focus )}.sky-split-view-drawer{background:var(--sky-override-split-view-drawer-background-color, transparent);overflow:auto;height:100%;width:100%}@media (min-width: 768px){:host .sky-split-view-drawer{border-right:var(--sky-override-split-view-drawer-border-right, var(--sky-border-width-divider) solid var(--sky-color-border-divider))}}:host-context(.sky-responsive-container-sm) .sky-split-view-drawer,:host-context(.sky-responsive-container-md) .sky-split-view-drawer,:host-context(.sky-responsive-container-lg) .sky-split-view-drawer{border-right:var(--sky-override-split-view-drawer-border-right, var(--sky-border-width-divider) solid var(--sky-color-border-divider))}.sky-split-view-resize-handle{-webkit-appearance:none;-moz-appearance:none;height:100%;width:var(--sky-override-split-view-resize-handle-width, var(--sky-size-width-resize_handle));position:absolute;z-index:999;cursor:ew-resize;padding:0;border:0;background:transparent;display:block;top:0;bottom:0;transition:box-shadow .15s}.sky-split-view-resize-handle:focus{border:var(--sky-override-split-view-resize-handle-border-focus, solid var(--sky-border-width-action-focus) var(--sky-color-border-action-tertiary-focus));box-shadow:var(--sky-override-split-view-resize-handle-box-shadow-focus, none);outline:var(--sky-override-split-view-resize-handle-outline-focus, none)}.sky-split-view-resize-handle::-moz-range-thumb,.sky-split-view-resize-handle::-moz-range-track{-webkit-appearance:none;-moz-appearance:none;width:0;height:0;border-radius:0;border:0 none;background:none;display:none}.sky-split-view-resize-handle::-ms-thumb,.sky-split-view-resize-handle::-ms-track{-webkit-appearance:none;-moz-appearance:none;width:0;height:0;border-radius:0;border:0 none;background:none;display:none}.sky-split-view-resize-handle::-webkit-slider-thumb{-webkit-appearance:none;-moz-appearance:none;width:0;height:0;border-radius:0;border:0 none;background:none;display:none}\n"] }]
        }], ctorParameters: () => [{ type: i0.ChangeDetectorRef }, { type: i1$1.SkyCoreAdapterService }, { type: SkySplitViewService }, { type: i1$1.SkyAppWindowRef }], propDecorators: { ariaLabel: [{
                type: Input
            }], width: [{
                type: Input
            }], onWindowResize: [{
                type: HostListener,
                args: ['window:resize', ['$event']]
            }] } });

/**
 * Specifies the content to display in the split view's workspace panel.
 */
class SkySplitViewWorkspaceContentComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewWorkspaceContentComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.14", type: SkySplitViewWorkspaceContentComponent, isStandalone: true, selector: "sky-split-view-workspace-content", host: { attributes: { "tabindex": "0" } }, hostDirectives: [{ directive: i1$1.SkyResponsiveHostDirective }], ngImport: i0, template: "<div class=\"sky-split-view-workspace-content\">\n  <ng-content />\n</div>\n", styles: [":host{display:block;overflow:auto;flex-grow:1}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewWorkspaceContentComponent, decorators: [{
            type: Component,
            args: [{ changeDetection: ChangeDetectionStrategy.OnPush, host: {
                        tabindex: '0',
                    }, hostDirectives: [SkyResponsiveHostDirective], selector: 'sky-split-view-workspace-content', standalone: true, template: "<div class=\"sky-split-view-workspace-content\">\n  <ng-content />\n</div>\n", styles: [":host{display:block;overflow:auto;flex-grow:1}\n"] }]
        }] });

/**
 * Specifies the footer to display in the split view's workspace panel. This component is often used with a summary action bar.
 */
class SkySplitViewWorkspaceFooterComponent {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewWorkspaceFooterComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.14", type: SkySplitViewWorkspaceFooterComponent, isStandalone: true, selector: "sky-split-view-workspace-footer", hostDirectives: [{ directive: i1$1.SkyResponsiveHostDirective }], ngImport: i0, template: "<div class=\"sky-split-view-workspace-footer sky-elevation-3\">\n  <ng-content />\n</div>\n", styles: [".sky-split-view-workspace-footer:not(.sky-theme-modern *){--sky-override-split-view-workspace-footer-padding: 10px;--sky-override-split-view-workspace-footer-box-shadow: 0 -3px 3px 0 #cdcfd2}:host-context(.sky-theme-modern:not(.sky-theme-brand-base)) .sky-split-view-workspace-footer{--sky-override-split-view-workspace-footer-box-shadow: 0 -3px 3px 0 #cdcfd2}:host{display:block;flex-shrink:0}.sky-split-view-workspace-footer{padding:var(--sky-override-split-view-workspace-footer-padding, var(--sky-comp-split_view-footer-space-inset-top) var(--sky-comp-split_view-footer-space-inset-right) var(--sky-comp-split_view-footer-space-inset-bottom) var(--sky-comp-split_view-footer-space-inset-left));box-shadow:var(--sky-override-split-view-workspace-footer-box-shadow, var(--sky-elevation-overflow))}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewWorkspaceFooterComponent, decorators: [{
            type: Component,
            args: [{ changeDetection: ChangeDetectionStrategy.OnPush, hostDirectives: [SkyResponsiveHostDirective], selector: 'sky-split-view-workspace-footer', standalone: true, template: "<div class=\"sky-split-view-workspace-footer sky-elevation-3\">\n  <ng-content />\n</div>\n", styles: [".sky-split-view-workspace-footer:not(.sky-theme-modern *){--sky-override-split-view-workspace-footer-padding: 10px;--sky-override-split-view-workspace-footer-box-shadow: 0 -3px 3px 0 #cdcfd2}:host-context(.sky-theme-modern:not(.sky-theme-brand-base)) .sky-split-view-workspace-footer{--sky-override-split-view-workspace-footer-box-shadow: 0 -3px 3px 0 #cdcfd2}:host{display:block;flex-shrink:0}.sky-split-view-workspace-footer{padding:var(--sky-override-split-view-workspace-footer-padding, var(--sky-comp-split_view-footer-space-inset-top) var(--sky-comp-split_view-footer-space-inset-right) var(--sky-comp-split_view-footer-space-inset-bottom) var(--sky-comp-split_view-footer-space-inset-left));box-shadow:var(--sky-override-split-view-workspace-footer-box-shadow, var(--sky-elevation-overflow))}\n"] }]
        }] });

/**
 * Specifies the header to display in the split view's workspace panel.
 * @internal
 */
class SkySplitViewWorkspaceHeaderComponent {
    #ngUnsubscribe = new Subject();
    #splitViewSvc;
    constructor(splitViewSvc) {
        this.#splitViewSvc = splitViewSvc;
    }
    ngOnInit() {
        this.#splitViewSvc.backButtonTextStream
            .pipe(takeUntil(this.#ngUnsubscribe))
            .subscribe((text) => {
            this.backButtonText = text;
        });
    }
    onShowDrawerButtonClick() {
        this.#splitViewSvc.backButtonClick();
    }
    ngOnDestroy() {
        this.#ngUnsubscribe.next();
        this.#ngUnsubscribe.complete();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewWorkspaceHeaderComponent, deps: [{ token: SkySplitViewService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.14", type: SkySplitViewWorkspaceHeaderComponent, isStandalone: true, selector: "sky-split-view-workspace-header", ngImport: i0, template: "<div class=\"sky-split-view-workspace-header\">\n  <div class=\"sky-split-view-workspace-header-content\">\n    <button\n      class=\"sky-btn sky-btn-link\"\n      type=\"button\"\n      (click)=\"onShowDrawerButtonClick()\"\n    >\n      <sky-icon iconName=\"chevron-left\" />\n      {{ backButtonText }}\n    </button>\n  </div>\n</div>\n", styles: [".sky-split-view-workspace-header:not(.sky-theme-modern *){--sky-override-split-view-header-border-bottom: 1px solid #cdcfd2;--sky-override-split-view-header-padding: 5px 0}:host-context(.sky-theme-modern:not(.sky-theme-brand-base)) .sky-split-view-workspace-header{--sky-override-split-view-header-padding: 5px 0}.sky-split-view-workspace-header{display:flex;align-items:flex-start;justify-content:flex-end;border-bottom:var(--sky-override-split-view-header-border-bottom, var(--sky-border-width-divider) solid var(--sky-color-border-divider));padding:var(--sky-override-split-view-header-padding, var(--sky-space-inset-balanced-none))}.sky-split-view-workspace-header .sky-split-view-workspace-header-content{flex-grow:1}\n"], dependencies: [{ kind: "ngmodule", type: SkyIconModule }, { kind: "component", type: i2.λ1, selector: "sky-icon", inputs: ["icon", "iconName", "iconType", "size", "fixedWidth", "variant", "iconSize"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewWorkspaceHeaderComponent, decorators: [{
            type: Component,
            args: [{ changeDetection: ChangeDetectionStrategy.OnPush, imports: [SkyIconModule], selector: 'sky-split-view-workspace-header', template: "<div class=\"sky-split-view-workspace-header\">\n  <div class=\"sky-split-view-workspace-header-content\">\n    <button\n      class=\"sky-btn sky-btn-link\"\n      type=\"button\"\n      (click)=\"onShowDrawerButtonClick()\"\n    >\n      <sky-icon iconName=\"chevron-left\" />\n      {{ backButtonText }}\n    </button>\n  </div>\n</div>\n", styles: [".sky-split-view-workspace-header:not(.sky-theme-modern *){--sky-override-split-view-header-border-bottom: 1px solid #cdcfd2;--sky-override-split-view-header-padding: 5px 0}:host-context(.sky-theme-modern:not(.sky-theme-brand-base)) .sky-split-view-workspace-header{--sky-override-split-view-header-padding: 5px 0}.sky-split-view-workspace-header{display:flex;align-items:flex-start;justify-content:flex-end;border-bottom:var(--sky-override-split-view-header-border-bottom, var(--sky-border-width-divider) solid var(--sky-color-border-divider));padding:var(--sky-override-split-view-header-padding, var(--sky-space-inset-balanced-none))}.sky-split-view-workspace-header .sky-split-view-workspace-header-content{flex-grow:1}\n"] }]
        }], ctorParameters: () => [{ type: SkySplitViewService }] });

/**
 * Contains the content, footer, and header to display in the split view's workspace panel.
 */
class SkySplitViewWorkspaceComponent {
    constructor() {
        // Use the parent's breakpoint since the mobile header should only appear when
        // the split view container as a whole reaches the "xs" breakpoint, not just
        // the workspace area.
        this.breakpoint = toSignal(inject(SkyMediaQueryService, { skipSelf: true }).breakpointChange);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewWorkspaceComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.14", type: SkySplitViewWorkspaceComponent, isStandalone: true, selector: "sky-split-view-workspace", inputs: { ariaLabel: "ariaLabel" }, ngImport: i0, template: "<div\n  class=\"sky-split-view-workspace\"\n  role=\"region\"\n  tabindex=\"0\"\n  [attr.aria-label]=\"ariaLabel\"\n>\n  @if (breakpoint() === 'xs') {\n    <sky-split-view-workspace-header />\n  }\n  <ng-content select=\"sky-split-view-workspace-content\" />\n  <ng-content select=\"sky-split-view-workspace-footer\" />\n</div>\n", styles: [".sky-split-view-workspace:not(.sky-theme-modern *){--sky-override-split-view-workspace-background-color: #ffffff}.sky-split-view-workspace{background:var(--sky-override-split-view-workspace-background-color, var(--sky-color-background-container-base));height:100%;display:flex;flex-direction:column}\n"], dependencies: [{ kind: "component", type: SkySplitViewWorkspaceHeaderComponent, selector: "sky-split-view-workspace-header" }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewWorkspaceComponent, decorators: [{
            type: Component,
            args: [{ changeDetection: ChangeDetectionStrategy.OnPush, imports: [SkySplitViewWorkspaceHeaderComponent], selector: 'sky-split-view-workspace', template: "<div\n  class=\"sky-split-view-workspace\"\n  role=\"region\"\n  tabindex=\"0\"\n  [attr.aria-label]=\"ariaLabel\"\n>\n  @if (breakpoint() === 'xs') {\n    <sky-split-view-workspace-header />\n  }\n  <ng-content select=\"sky-split-view-workspace-content\" />\n  <ng-content select=\"sky-split-view-workspace-footer\" />\n</div>\n", styles: [".sky-split-view-workspace:not(.sky-theme-modern *){--sky-override-split-view-workspace-background-color: #ffffff}.sky-split-view-workspace{background:var(--sky-override-split-view-workspace-background-color, var(--sky-color-background-container-base));height:100%;display:flex;flex-direction:column}\n"] }]
        }], propDecorators: { ariaLabel: [{
                type: Input
            }] } });

/**
 * Adapter service for use when the split view component needs to manipulate the DOM
 * @internal
 */
class SkySplitViewAdapterService {
    #observer;
    #renderer;
    #observerSvc;
    #rendererFactory;
    #windowRef;
    constructor(observerSvc, rendererFactory, windowRef) {
        this.#observerSvc = observerSvc;
        this.#rendererFactory = rendererFactory;
        this.#windowRef = windowRef;
        this.#renderer = this.#rendererFactory.createRenderer(undefined, null);
    }
    bindHeightToWindow(elementRef, unsubscribeSubject) {
        /*istanbul ignore else*/
        if (elementRef.nativeElement.offsetParent === document.body) {
            this.#observer = this.#observerSvc.create(() => {
                this.#setSplitViewBoundHeights(elementRef);
            });
            fromEvent(this.#windowRef.nativeWindow, 'resize')
                .pipe(takeUntil(unsubscribeSubject))
                .subscribe(() => {
                this.#setSplitViewBoundHeights(elementRef);
            });
            const config = {
                attributes: true,
                attributeFilter: ['style'],
                childList: false,
                characterDate: false,
            };
            // This observer makes sure that the split view reacts if the body styling is change but thing
            // such as the action bar.
            this.#observer.observe(document.body, config);
            this.#setSplitViewBoundHeights(elementRef);
            unsubscribeSubject.pipe(take(1)).subscribe(() => {
                this.#observer?.disconnect();
                const splitViewElement = elementRef.nativeElement.querySelector('.sky-split-view');
                this.#renderer.removeStyle(splitViewElement, 'max-height');
                this.#renderer.removeStyle(splitViewElement, 'min-height');
            });
        }
    }
    #setSplitViewBoundHeights(elementRef) {
        const splitViewElement = elementRef.nativeElement.querySelector('.sky-split-view');
        const offsetTop = splitViewElement.offsetTop;
        const marginBottom = document.body.style.marginBottom
            ? document.body.style.marginBottom
            : '0px';
        this.#renderer.setStyle(splitViewElement, 'max-height', 'calc(100vh - ' + offsetTop + 'px - ' + marginBottom + ')');
        this.#renderer.setStyle(splitViewElement, 'min-height', '300px');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewAdapterService, deps: [{ token: i1$1.SkyMutationObserverService }, { token: i0.RendererFactory2 }, { token: i1$1.SkyAppWindowRef }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewAdapterService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewAdapterService, decorators: [{
            type: Injectable
        }], ctorParameters: () => [{ type: i1$1.SkyMutationObserverService }, { type: i0.RendererFactory2 }, { type: i1$1.SkyAppWindowRef }] });

var SkySplitViewMessageType;
(function (SkySplitViewMessageType) {
    /**
     * Places focus on the first focusable element in the workspace.
     */
    SkySplitViewMessageType[SkySplitViewMessageType["FocusWorkspace"] = 0] = "FocusWorkspace";
})(SkySplitViewMessageType || (SkySplitViewMessageType = {}));

/**
 * Displays a list alongside a workspace where users can view details for selected items
 * and take actions.
 */
class SkySplitViewComponent {
    /**
     * The label for the button that appears in the workspace header in responsive mode.
     * The button returns users to the list.
     * @default "Back to list"
     */
    set backButtonText(value) {
        if (value) {
            this.#splitViewService.updateBackButtonText(value);
        }
    }
    /**
     * Whether the split view's height is bound to the window height.
     * @default false
     * @deprecated We recommend using the `dock` input instead. An example of this can
     * be found in the developer code examples.
     */
    set bindHeightToWindow(bindToHeight) {
        this.#_bindHeightToWindow = bindToHeight;
        if (this.#bindHeightToWindowUnsubscribe) {
            this.#bindHeightToWindowUnsubscribe.next();
            this.#bindHeightToWindowUnsubscribe.complete();
        }
        if (bindToHeight) {
            this.#bindHeightToWindowUnsubscribe = new Subject();
            this.#adapter.bindHeightToWindow(this.#elementRef, this.#bindHeightToWindowUnsubscribe);
        }
    }
    get bindHeightToWindow() {
        return this.#_bindHeightToWindow;
    }
    /**
     * How the split view docks to its container. Use `fill` to dock
     * the split view to the container's size where the container is a `sky-page` component
     * with its `layout` input set to `fit`, or where the container is another element with
     * a relative or absolute position and a fixed size.
     * @default "none"
     */
    set dock(value) {
        this.#_dock = value || 'none';
    }
    get dock() {
        return this.#_dock;
    }
    set drawerVisible(value) {
        this.#_drawerVisible = value;
        this.#changeDetectorRef.markForCheck();
    }
    get drawerVisible() {
        return !this.isMobile || this.#_drawerVisible;
    }
    get workspaceVisible() {
        return !this.isMobile || !this.#_drawerVisible;
    }
    #animationComplete;
    #bindHeightToWindowUnsubscribe;
    #ngUnsubscribe;
    #adapter;
    #changeDetectorRef;
    #coreAdapterService;
    #elementRef;
    #splitViewService;
    #_bindHeightToWindow;
    #_drawerVisible;
    #_dock;
    constructor(adapter, changeDetectorRef, coreAdapterService, elementRef, splitViewService) {
        /**
         * The observable that sends commands to the split view component.
         * The commands should respect the `SkySplitViewMessage` type.
         */
        this.messageStream = new Subject();
        this.isMobile = false;
        this.nextButtonDisabled = false;
        this.previousButtonDisabled = false;
        this.#animationComplete = new Subject();
        this.#ngUnsubscribe = new Subject();
        this.#_bindHeightToWindow = false;
        this.#_drawerVisible = true;
        this.#_dock = 'none';
        this.#adapter = adapter;
        this.#changeDetectorRef = changeDetectorRef;
        this.#coreAdapterService = coreAdapterService;
        this.#elementRef = elementRef;
        this.#splitViewService = splitViewService;
        splitViewService.splitViewElementRef = elementRef;
    }
    ngOnInit() {
        this.#splitViewService.isMobileStream
            .pipe(takeUntil(this.#ngUnsubscribe))
            .subscribe((mobile) => {
            this.isMobile = mobile;
            this.#changeDetectorRef.markForCheck();
        });
        this.#splitViewService.drawerVisible
            .pipe(takeUntil(this.#ngUnsubscribe))
            .subscribe((visible) => {
            this.drawerVisible = visible;
        });
        this.messageStream
            .pipe(takeUntil(this.#ngUnsubscribe))
            .subscribe((message) => {
            this.#handleIncomingMessages(message);
        });
    }
    ngOnDestroy() {
        if (this.#bindHeightToWindowUnsubscribe) {
            this.#bindHeightToWindowUnsubscribe.next();
            this.#bindHeightToWindowUnsubscribe.complete();
        }
        this.#ngUnsubscribe.next();
        this.#ngUnsubscribe.complete();
    }
    onWorkspaceEnterComplete() {
        this.#animationComplete.next();
    }
    #applyAutofocus() {
        const applyAutoFocus = this.#coreAdapterService.applyAutoFocus(this.#elementRef);
        /*istanbul ignore else*/
        if (!applyAutoFocus) {
            this.#coreAdapterService.getFocusableChildrenAndApplyFocus(this.#elementRef, '.sky-split-view-workspace-content');
        }
    }
    #handleIncomingMessages(message) {
        switch (message.type) {
            case SkySplitViewMessageType.FocusWorkspace:
                // If mobile, wait until animation is complete then set focus on workspace panel.
                // Otherwise, just set focus right away.
                if (!this.workspaceVisible) {
                    this.drawerVisible = false;
                    this.#animationComplete.pipe(take(1)).subscribe(() => {
                        this.#applyAutofocus();
                    });
                }
                else {
                    this.#applyAutofocus();
                }
                this.#changeDetectorRef.markForCheck();
                break;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewComponent, deps: [{ token: SkySplitViewAdapterService }, { token: i0.ChangeDetectorRef }, { token: i1$1.SkyCoreAdapterService }, { token: i0.ElementRef }, { token: SkySplitViewService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.14", type: SkySplitViewComponent, isStandalone: true, selector: "sky-split-view", inputs: { backButtonText: "backButtonText", bindHeightToWindow: "bindHeightToWindow", dock: "dock", messageStream: "messageStream" }, providers: [SkySplitViewAdapterService, SkySplitViewService], queries: [{ propertyName: "drawerComponent", first: true, predicate: SkySplitViewDrawerComponent, descendants: true }], hostDirectives: [{ directive: i1$1.SkyResponsiveHostDirective }], ngImport: i0, template: "<div\n  class=\"sky-split-view\"\n  [ngClass]=\"'sky-split-view-dock-' + dock\"\n  [@blockAnimationOnLoad]\n>\n  <div\n    class=\"sky-split-view-drawer-flex-container\"\n    [hidden]=\"!drawerVisible\"\n    [@drawerEnter]=\"drawerVisible\"\n  >\n    <ng-content select=\"sky-split-view-drawer\" />\n  </div>\n\n  <div\n    class=\"sky-split-view-workspace-flex-container\"\n    [hidden]=\"!workspaceVisible\"\n    [@workspaceEnter]=\"workspaceVisible\"\n    (@workspaceEnter.done)=\"onWorkspaceEnterComplete()\"\n  >\n    <ng-content select=\"sky-split-view-workspace\" />\n  </div>\n</div>\n", styles: [".sky-split-view:not(.sky-theme-modern *){--sky-override-split-view-border: 1px solid #cdcfd2;--sky-override-split-view-border-left: 1px solid #cdcfd2}:host{display:block}.sky-split-view{position:relative;display:flex;border:var(--sky-override-split-view-border, var(--sky-border-width-divider) solid var(--sky-color-border-divider));background:transparent;margin:var(--sky-layout-host-content-spacing, 0);max-height:100%}.sky-split-view .sky-split-view-workspace-flex-container{flex-grow:1;flex-shrink:99;overflow:auto}.sky-split-view-dock-fill{position:absolute;inset:0}:host .sky-split-view-drawer-flex-container{width:100%}:host-context(.sky-responsive-container-xs) .sky-split-view-drawer-flex-container,:host-context(.sky-responsive-container-sm) .sky-split-view-drawer-flex-container,:host-context(.sky-responsive-container-md) .sky-split-view-drawer-flex-container,:host-context(.sky-responsive-container-lg) .sky-split-view-drawer-flex-container{width:100%}@media (min-width: 768px){:host .sky-split-view-drawer-flex-container{width:auto}}:host-context(.sky-responsive-container-sm) .sky-split-view-drawer-flex-container,:host-context(.sky-responsive-container-md) .sky-split-view-drawer-flex-container,:host-context(.sky-responsive-container-lg) .sky-split-view-drawer-flex-container{width:auto}@media (min-width: 768px){:host .sky-split-view{border-left:var(--sky-override-split-view-border-left, none)}}:host-context(.sky-responsive-container-sm) .sky-split-view,:host-context(.sky-responsive-container-md) .sky-split-view,:host-context(.sky-responsive-container-lg) .sky-split-view{border-left:var(--sky-override-split-view-border-left, none)}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i4.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }], animations: [
            trigger('blockAnimationOnLoad', [transition(':enter', [])]),
            trigger('drawerEnter', [
                state('false', style({ transform: 'translate(-100%)' })),
                transition('* => true', animate('150ms ease-in')),
            ]),
            trigger('workspaceEnter', [
                state('false', style({ transform: 'translate(100%)' })),
                transition('* => true', animate('150ms ease-in')),
            ]),
        ], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewComponent, decorators: [{
            type: Component,
            args: [{ animations: [
                        trigger('blockAnimationOnLoad', [transition(':enter', [])]),
                        trigger('drawerEnter', [
                            state('false', style({ transform: 'translate(-100%)' })),
                            transition('* => true', animate('150ms ease-in')),
                        ]),
                        trigger('workspaceEnter', [
                            state('false', style({ transform: 'translate(100%)' })),
                            transition('* => true', animate('150ms ease-in')),
                        ]),
                    ], changeDetection: ChangeDetectionStrategy.OnPush, hostDirectives: [SkyResponsiveHostDirective], imports: [CommonModule], providers: [SkySplitViewAdapterService, SkySplitViewService], selector: 'sky-split-view', template: "<div\n  class=\"sky-split-view\"\n  [ngClass]=\"'sky-split-view-dock-' + dock\"\n  [@blockAnimationOnLoad]\n>\n  <div\n    class=\"sky-split-view-drawer-flex-container\"\n    [hidden]=\"!drawerVisible\"\n    [@drawerEnter]=\"drawerVisible\"\n  >\n    <ng-content select=\"sky-split-view-drawer\" />\n  </div>\n\n  <div\n    class=\"sky-split-view-workspace-flex-container\"\n    [hidden]=\"!workspaceVisible\"\n    [@workspaceEnter]=\"workspaceVisible\"\n    (@workspaceEnter.done)=\"onWorkspaceEnterComplete()\"\n  >\n    <ng-content select=\"sky-split-view-workspace\" />\n  </div>\n</div>\n", styles: [".sky-split-view:not(.sky-theme-modern *){--sky-override-split-view-border: 1px solid #cdcfd2;--sky-override-split-view-border-left: 1px solid #cdcfd2}:host{display:block}.sky-split-view{position:relative;display:flex;border:var(--sky-override-split-view-border, var(--sky-border-width-divider) solid var(--sky-color-border-divider));background:transparent;margin:var(--sky-layout-host-content-spacing, 0);max-height:100%}.sky-split-view .sky-split-view-workspace-flex-container{flex-grow:1;flex-shrink:99;overflow:auto}.sky-split-view-dock-fill{position:absolute;inset:0}:host .sky-split-view-drawer-flex-container{width:100%}:host-context(.sky-responsive-container-xs) .sky-split-view-drawer-flex-container,:host-context(.sky-responsive-container-sm) .sky-split-view-drawer-flex-container,:host-context(.sky-responsive-container-md) .sky-split-view-drawer-flex-container,:host-context(.sky-responsive-container-lg) .sky-split-view-drawer-flex-container{width:100%}@media (min-width: 768px){:host .sky-split-view-drawer-flex-container{width:auto}}:host-context(.sky-responsive-container-sm) .sky-split-view-drawer-flex-container,:host-context(.sky-responsive-container-md) .sky-split-view-drawer-flex-container,:host-context(.sky-responsive-container-lg) .sky-split-view-drawer-flex-container{width:auto}@media (min-width: 768px){:host .sky-split-view{border-left:var(--sky-override-split-view-border-left, none)}}:host-context(.sky-responsive-container-sm) .sky-split-view,:host-context(.sky-responsive-container-md) .sky-split-view,:host-context(.sky-responsive-container-lg) .sky-split-view{border-left:var(--sky-override-split-view-border-left, none)}\n"] }]
        }], ctorParameters: () => [{ type: SkySplitViewAdapterService }, { type: i0.ChangeDetectorRef }, { type: i1$1.SkyCoreAdapterService }, { type: i0.ElementRef }, { type: SkySplitViewService }], propDecorators: { backButtonText: [{
                type: Input
            }], bindHeightToWindow: [{
                type: Input
            }], dock: [{
                type: Input
            }], messageStream: [{
                type: Input
            }], drawerComponent: [{
                type: ContentChild,
                args: [SkySplitViewDrawerComponent]
            }] } });

class SkySplitViewModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewModule, imports: [SkySplitViewComponent,
            SkySplitViewDrawerComponent,
            SkySplitViewWorkspaceComponent,
            SkySplitViewWorkspaceContentComponent,
            SkySplitViewWorkspaceFooterComponent,
            SkySplitViewWorkspaceHeaderComponent], exports: [SkySplitViewComponent,
            SkySplitViewDrawerComponent,
            SkySplitViewWorkspaceComponent,
            SkySplitViewWorkspaceContentComponent,
            SkySplitViewWorkspaceFooterComponent,
            SkySplitViewWorkspaceHeaderComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewModule, imports: [SkySplitViewComponent,
            SkySplitViewDrawerComponent,
            SkySplitViewWorkspaceComponent,
            SkySplitViewWorkspaceHeaderComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SkySplitViewModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        SkySplitViewComponent,
                        SkySplitViewDrawerComponent,
                        SkySplitViewWorkspaceComponent,
                        SkySplitViewWorkspaceContentComponent,
                        SkySplitViewWorkspaceFooterComponent,
                        SkySplitViewWorkspaceHeaderComponent,
                    ],
                    exports: [
                        SkySplitViewComponent,
                        SkySplitViewDrawerComponent,
                        SkySplitViewWorkspaceComponent,
                        SkySplitViewWorkspaceContentComponent,
                        SkySplitViewWorkspaceFooterComponent,
                        SkySplitViewWorkspaceHeaderComponent,
                    ],
                }]
        }] });

// Split view modules.

/**
 * Generated bundle index. Do not edit.
 */

export { SkySplitViewMessageType, SkySplitViewModule, SkySplitViewComponent as λ1, SkySplitViewDrawerComponent as λ2, SkySplitViewWorkspaceComponent as λ3, SkySplitViewWorkspaceContentComponent as λ4, SkySplitViewWorkspaceFooterComponent as λ5, SkySplitViewWorkspaceHeaderComponent as λ6 };
//# sourceMappingURL=skyux-split-view.mjs.map
