import { ChangeDetectorRef, ElementRef, OnDestroy, OnInit } from '@angular/core';
import { SkyCoreAdapterService } from '@skyux/core';
import { Subject } from 'rxjs';
import { SkySplitViewAdapterService } from './split-view-adapter.service';
import { SkySplitViewDrawerComponent } from './split-view-drawer.component';
import { SkySplitViewService } from './split-view.service';
import { SkySplitViewDockType } from './types/split-view-dock-type';
import { SkySplitViewMessage } from './types/split-view-message';
import * as i0 from "@angular/core";
import * as i1 from "@skyux/core";
/**
 * Displays a list alongside a workspace where users can view details for selected items
 * and take actions.
 */
export declare class SkySplitViewComponent implements OnInit, OnDestroy {
    #private;
    /**
     * The label for the button that appears in the workspace header in responsive mode.
     * The button returns users to the list.
     * @default "Back to list"
     */
    set backButtonText(value: string);
    /**
     * Whether the split view's height is bound to the window height.
     * @default false
     * @deprecated We recommend using the `dock` input instead. An example of this can
     * be found in the developer code examples.
     */
    set bindHeightToWindow(bindToHeight: boolean);
    get bindHeightToWindow(): boolean;
    /**
     * How the split view docks to its container. Use `fill` to dock
     * the split view to the container's size where the container is a `sky-page` component
     * with its `layout` input set to `fit`, or where the container is another element with
     * a relative or absolute position and a fixed size.
     * @default "none"
     */
    set dock(value: SkySplitViewDockType | undefined);
    get dock(): SkySplitViewDockType;
    /**
     * The observable that sends commands to the split view component.
     * The commands should respect the `SkySplitViewMessage` type.
     */
    messageStream: Subject<SkySplitViewMessage>;
    drawerComponent: SkySplitViewDrawerComponent | undefined;
    set drawerVisible(value: boolean);
    get drawerVisible(): boolean;
    isMobile: boolean;
    nextButtonDisabled: boolean;
    previousButtonDisabled: boolean;
    get workspaceVisible(): boolean;
    constructor(adapter: SkySplitViewAdapterService, changeDetectorRef: ChangeDetectorRef, coreAdapterService: SkyCoreAdapterService, elementRef: ElementRef, splitViewService: SkySplitViewService);
    ngOnInit(): void;
    ngOnDestroy(): void;
    onWorkspaceEnterComplete(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SkySplitViewComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SkySplitViewComponent, "sky-split-view", never, { "backButtonText": { "alias": "backButtonText"; "required": false; }; "bindHeightToWindow": { "alias": "bindHeightToWindow"; "required": false; }; "dock": { "alias": "dock"; "required": false; }; "messageStream": { "alias": "messageStream"; "required": false; }; }, {}, ["drawerComponent"], ["sky-split-view-drawer", "sky-split-view-workspace"], true, [{ directive: typeof i1.SkyResponsiveHostDirective; inputs: {}; outputs: {}; }]>;
}
